<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\History;
use App\Models\User;
use App\Notifications\TradeOpenNotification;
use App\Notifications\TradeCloseNotification;

class HistoryController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $history = History::all();
        return view('admin.history')->with('history' , $history);
    }

    public function view()
    {
        $usercount     = User::count();
        $users = User::paginate(5);
        return view('admin.history.user', compact('usercount', 'users'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create($id)
    {
        $user = User::find($id);
        
        return view('admin.history.create' , compact('user'));
    }


    public function usertrade($id)
    {
        $user = User::find($id);
        $history = History::find($user);
     
        return view('admin.history.view' , compact('history', 'user'));
    }
    

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $data = $request->all();
        History::create($request->all());

       
        
        \Notification::route('mail', $request->input('email'))
            ->notify(new TradeOpenNotification($data));
        
        return redirect()->route('trade.history')->with('error', 'TRade history Added succesfully');

    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $history = History::find($id);
        return view('admin.historyedit')->with('history', $history);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {

        $data = $request->all();


        $history = History::find($id);
        $history->name = $request->input('name');
        $history->email = $request->input('email');
        $history->amount = $request->input('amount');
        $history->trade = $request->input('trade');
        $history->date = $request->input('date');
        $history->time = $request->input('time');
        $history->status = $request->input('status');
        $history->currency = $request->input('currency');
        
        $history->update();

        \Notification::route('mail', $request->input('email'))
            ->notify(new TradeCloseNotification($data));

        return redirect()->route('trade.history')->with('error',  'Trade Information Updated Successfully....');
    }
    

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $history = History::find($id);
        $history->delete();
        return redirect()->back()->with('error',  'Trade Information Deleted Successfully....');
    }
}
