<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Invoice;
use App\Models\User;
use App\Notifications\InvoiceCreateNotification;
use App\Notifications\InvoiceCloseNotification;

class InvoiceController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $invoice = Invoice::all();
        return view('admin.invoice.dashboard')->with('invoice' , $invoice);

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create($id)
    {

        $user = User::find($id);
        return view('admin.invoice.create', compact('user'));
    }

    public function view($id)
    {

        $user_id = $id;
        $invoice = Invoice::with('user')->where('user_id', $user_id)->get();

        return view('admin.invoice.view', compact('invoice'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $data = $request->all();
        Invoice::create($request->all());
        
        \Notification::route('mail', $request->input('email'))
            ->notify(new InvoiceCreateNotification($data));
        
        return redirect()->route('admin.dashboard')->with('error', 'INVOICE CREATED AND SEND SUCCESFULLY');
       
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $invoice = Invoice::find($id);
        return view('admin.invoice.edit')->with('invoice' , $invoice);

    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $data = $request->all();
        
        $invoice = Invoice::find($id);
     
        $invoice->name = $request->input('name');
        $invoice->email = $request->input('email');
        $invoice->amount = $request->input('amount');
        $invoice->invoiceid = $request->input('invoiceid');
        $invoice->by = $request->input('by');
        $invoice->body = $request->input('body');
        $invoice->complimentry = $request->input('complimentry');
        
        
        $invoice->update();

        \Notification::route('mail', $request->input('email'))
            ->notify(new InvoiceCloseNotification($data));

        return redirect()->route('admin.dashboard')->with('error',  'PAYMENT APPROVE AND INVOICE SEND SUCCESSFULLY....');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
