<?php

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\AdminController;
use App\Http\Controllers\DashboardController;
use App\Http\Controllers\CustomController;
use App\Http\Controllers\UserController;
use App\Http\Controllers\HistoryController;
use App\Http\Controllers\DepositController;
use App\Http\Controllers\WithdrawController;
use App\Http\Controllers\ActionController;
use App\Http\Controllers\TicketController;
use App\Http\Controllers\MessageController;
use App\Http\Controllers\InvoiceController;
use App\Http\Controllers\CommentController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/
//User Controller
Route::prefix('user')->group(function(){

    Route::get('/', [UserController::class, 'index'])->name('user');
 
    Route::get('/edit/{id}', [UserController::class, 'edit'])->name('user.edit');

    Route::get('/history/{id}', [HistoryController::class, 'create'])->name('history.create');
  
    Route::get('/code/message/{id}', [MessageController::class, 'index'])->name('message.sendnew')->middleware('auth:admin');
 
    Route::get('/create/message/{id}', [MessageController::class, 'createnew'])->name('message.codenew')->middleware('auth:admin');
    Route::get('/create/invoice/{id}', [InvoiceController::class, 'create'])->name('invoice.createnew');
   
    Route::any('/update/{id}', [UserController::class, 'update'])->name('user.update');

    Route::any('/delete/{id}', [UserController::class, 'destroy'])->name('user.destroy');
    

});

//History Controller

Route::prefix('history')->group(function(){

    Route::get('/', [HistoryController::class, 'index'])->name('history');
    Route::get('/user/view', [HistoryController::class, 'view'])->name('trade.history');
    Route::get('/show/{id}', [HistoryController::class, 'usertrade'])->name('history.view');
    Route::post('/store', [HistoryController::class, 'store'])->name('history.store');
    Route::any('/update/{id}', [HistoryController::class, 'update'])->name('history.update');

    Route::get('/edit/{id}', [HistoryController::class, 'edit'])->name('history.edit');
    Route::post('/destroy', [HistoryController::class, 'destroy'])->name('history.destroy');
    

});

// Deposit Controller 

Route::prefix('deposit')->group(function(){

    Route::get('/', [DepositController::class, 'index'])->name('deposit')->middleware('auth:admin');
    Route::get('/show/{id}', [DepositController::class, 'view'])->name('deposit.view')->middleware('auth:admin');
    Route::post('/store', [DepositController::class, 'store'])->name('deposit.store');
    Route::get('/edit/{id}', [DepositController::class, 'edit'])->name('deposit.edit')->middleware('auth:admin');
    Route::any('/update/{id}', [DepositController::class, 'update'])->name('deposit.update')->middleware('auth:admin');
    Route::get('/destroy', [DepositController::class, 'destroy'])->name('deposit.destroy')->middleware('auth:admin');
    

});


// WITHDRAW CONTROLLER


Route::prefix('withdraw')->group(function(){

    Route::get('/', [WithdrawController::class, 'index'])->name('withdraw')->middleware('auth:admin');
    Route::get('/withdraw/{id}', [WithdrawController::class, 'view'])->name('withdraw.view')->middleware('auth:admin');
    Route::post('/store', [WithdrawController::class, 'store'])->name('withdraw.store');
    Route::get('/edit/{id}', [WithdrawController::class, 'edit'])->name('withdraw.edit')->middleware('auth:admin');
    Route::any('/update/{id}', [WithdrawController::class, 'update'])->name('withdraw.update')->middleware('auth:admin');
    Route::get('/destroy', [WithdrawController::class, 'destroy'])->name('withdraw.destroy')->middleware('auth:admin');
    

});


// ACTION CONTROLLER



Route::prefix('action')->group(function(){

    Route::get('/', [ActionController::class, 'index'])->name('action')->middleware('auth:admin');
    Route::get('/wallet-upload', [ActionController::class, 'wallet'])->name('wallet')->middleware('auth:admin');
    Route::get('/wallet-edit', [ActionController::class, 'walletview'])->name('walletview')->middleware('auth:admin');
    Route::post('/wallet-upload-post', [ActionController::class, 'walletcreate'])->name('walletcreate')->middleware('auth:admin');
    Route::any('/wallet-update-post/{id}', [ActionController::class, 'walletupdate'])->name('walletupdate')->middleware('auth:admin');
    Route::get('/bill', [ActionController::class, 'bill'])->name('action.bill')->middleware('auth:admin');
    Route::get('/wallet/edit/{id}', [ActionController::class, 'walletedit'])->name('wallet.edit')->middleware('auth:admin');
    Route::get('/edit/{id}', [ActionController::class, 'edit'])->name('action.edit')->middleware('auth:admin');
    Route::any('/update/{id}', [ActionController::class, 'update'])->name('action.update')->middleware('auth:admin');
    

});


//MESSAGE CONTROLLER
Route::prefix('message')->group(function(){

   Route::get('/', [MessageController::class, 'create'])->name('message')->middleware('auth:admin');
   Route::get('/create', [MessageController::class, 'create'])->name('message.code')->middleware('auth:admin');
    Route::post('/send', [MessageController::class, 'send'])->name('message.send')->middleware('auth:admin');
    Route::post('/send/code', [MessageController::class, 'code'])->name('message.codebill')->middleware('auth:admin');
    Route::get('/edit/{id}', [MessageController::class, 'edit'])->name('message.edit')->middleware('auth:admin');
    Route::any('/update/{id}', [MessageController::class, 'update'])->name('message.update')->middleware('auth:admin');
  

});

//TICKET CONTROLLER

Route::prefix('ticket')->group(function(){

    Route::get('/', [TicketController::class, 'index'])->name('ticket')->middleware('auth:admin');
    Route::get('/create', [TicketController::class, 'create'])->name('ticket.create')->middleware(['auth']);
    Route::post('/store', [TicketController::class, 'store'])->name('ticket.store');
    Route::get('/show/{id}', [TicketController::class, 'show'])->name('ticket.show');
    Route::get('/edit/{id}', [TicketController::class, 'edit'])->name('ticket.edit')->middleware('auth:admin');
    Route::any('/delelet/{id}', [TicketController::class, 'destroy'])->name('ticket.destroy')->middleware('auth:admin');
  

});

//COMMENT CONTROLLER

Route::prefix('comment')->group(function(){

    Route::get('/', [CommentController::class, 'index'])->name('comment');
    Route::get('/create', [CommentController::class, 'create'])->name('comment.create');
    Route::post('/store', [CommentController::class, 'store'])->name('comment.store');
    Route::get('/show/{id}', [CommentController::class, 'show'])->name('comment.show');
    Route::get('/edit/{id}', [CommentController::class, 'edit'])->name('comment.edit')->middleware('auth:admin');
    Route::post('/update', [CommentController::class, 'update'])->name('comment.update')->middleware('auth:admin');
  

});


//INVOICE CONTROLLER

Route::prefix('invoice')->group(function(){

    Route::get('/', [InvoiceController::class, 'index'])->name('invoice')->middleware('auth:admin');
    Route::get('/creat', [InvoiceController::class, 'show'])->name('invoice.create')->middleware('auth:admin');
    Route::get('/view/{id}', [InvoiceController::class, 'view'])->name('invoice.view');
    Route::post('/store', [InvoiceController::class, 'store'])->name('invoice.store');
    Route::get('/edit/{id}', [InvoiceController::class, 'edit'])->name('invoice.edit')->middleware('auth:admin');
    Route::any('/update/{id}', [InvoiceController::class, 'update'])->name('invoice.update')->middleware('auth:admin');
    Route::any('/delete/{id}', [InvoiceController::class, 'delete'])->name('invoice.destroy')->middleware('auth:admin');
  

});




//Dashboard Controller

Route::get('/home', [DashboardController::class, 'dash'])->name('dash')->middleware('verified');;
Route::get('/account', [DashboardController::class, 'account'])->name('account')->middleware('verified');;
Route::get('/trade', [DashboardController::class, 'trade'])->name('trade')->middleware('verified');;
Route::get('/make-withdraw', [DashboardController::class, 'withdraw'])->name('with');
Route::get('/profile-check', [DashboardController::class, 'profile'])->name('profile');
Route::get('/security-check', [DashboardController::class, 'security'])->name('security');
Route::get('/plan-check', [DashboardController::class, 'plan'])->name('plan');
Route::get('/history-withdraw', [DashboardController::class, 'withhistory'])->name('with-history');
Route::get('/history-trade', [DashboardController::class, 'tradehistory'])->name('tradehistory');
Route::get('/make-deposit', [DashboardController::class, 'deposit'])->name('depo');
Route::get('/history-deposit', [DashboardController::class, 'depohistory'])->name('depo-history');


Route::get('/verify', [DashboardController::class, 'verify'])->name('verify');
Route::get('/user-setting', [DashboardController::class, 'set'])->name('set');
Route::get('/user-pro', [DashboardController::class, 'pro'])->name('pro');
Route::get('/plan/upgrade', [DashboardController::class, 'upgrade'])->name('plan-upgrade');
Route::get('/user/logoff', [DashboardController::class, 'logout'])->name('user-logout')->middleware('auth');


Route::post('/walletprocess', [DashboardController::class, 'wallet'])->name('walletprocessing');
Route::post('/bankprocess', [DashboardController::class, 'bank'])->name('bankprocessing');


Route::get('/paymentprocessing', [DashboardController::class, 'form1'])->name('form1');
Route::get('/paymentprocessingxx', [DashboardController::class, 'form2'])->name('form2');
Route::get('/paymentprocessingxxxx', [DashboardController::class, 'form3'])->name('form3');
Route::get('/paymentprocessingxxyyxx', [DashboardController::class, 'form4'])->name('form4');
Route::get('/paymentprocessingxxyyyyxx', [DashboardController::class, 'form5'])->name('form5');
Route::get('/paymentprocessingxxyyyeeyxx', [DashboardController::class, 'completed'])->name('completed');

Route::any('/xtrade-checking', [CustomController::class, 'xtrade'])->name('xtrade-check');
Route::any('/document-checking', [CustomController::class, 'document'])->name('documet-upload');

Route::any('/proof-checking', [CustomController::class, 'proof'])->name('proof-upload');

Route::post('/payment/checking', [CustomController::class, 'type'])->name('payment-type');
Route::post('/payment/check', [CustomController::class, 'paymentcheck'])->name('payment-check');
Route::post('/upgrade-checking', [CustomController::class, 'upgrade'])->name('upgrade-post');
Route::get('/upgrade-update', [CustomController::class, 'check'])->name('upgrade-update');
Route::post('/checkingxxx', [CustomController::class, 'bill'])->name('bill1');
Route::post('/checkingxxxzz', [CustomController::class, 'bill2'])->name('bill2');
Route::post('/checkingrrxxxzz', [CustomController::class, 'bill3'])->name('bill3');
Route::post('/checkingrrxxxyyzz', [CustomController::class, 'bill4'])->name('bill4');
Route::post('/checkingrrxxxyyxxzz', [CustomController::class, 'bill5'])->name('bill5');

Route::any('/update/info', [CustomController::class, 'profileupdate'])->name('profile-update');
Route::post('/update/password', [CustomController::class, 'passwordupdate'])->name('password-update');


Route::get('/reg', [CustomController::class, 'reg'])->name('reg');
Route::get('/log', [DashboardController::class, 'log'])->name('log');


Route::get('/', function () {
    return view('welcome');
});

Route::get('/dashboard', function () {
    return view('dashboard');
})->middleware(['auth'])->name('dashboard');

require __DIR__.'/auth.php';




Route::prefix('admin')->group(function(){

    Route::get('/login', [AdminController::class, 'showLogin'])->name('admin-login');
    Route::get('/register', [AdminController::class, 'showReg'])->name('admin-register');
    
    Route::post('/login/post', [AdminController::class, 'login'])->name('adminLoginPost');
    Route::post('/register/post', [AdminController::class, 'register'])->name('adminRegisterPost');
    
    Route::get('/dashboard', [AdminController::class, 'dashboardnew'])->name('admin.dashboard')->middleware(['auth:admin']);
    Route::get('/logout', [AdminController::class, 'logout'])->name('admin-logout')->middleware('auth:admin');

});

require __DIR__.'/adminauth.php';



